==> xwidgetsbase-6.0.0.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItemWidget.dart <==
part of xwidgetbase;

class XItemWidget extends StatelessWidget {
  ///Figlio che si trova dentro l'XItemWidget
  final Widget? child;
  final String title;
  final Color? titleBackColor;
  final double? titleHeight;

  ///Altezza del Container sotto il Title
  final double? heightChildContainer;

  ///BTN all'interno del container del Title e viene messo sulla destra
  final Widget? btnOnTitle;
  final TextStyle? titleStyle;

  ///Lista dei Widget per Headers per definire colonne in una lista che hai nel child dell'XItemWidget
  final List<Widget>? childrenForHeaders;
  final AlignmentGeometry? titleAlignment;
  double borderWidth;

  ///BackGroundColor per il child interno sotto il Title
  final Color? backGroundColorInternalWidget;
  final Color? colorForAllBorder;

  ///Setta per dare una Decoration specializzata per quest'Item
  final Decoration? decorationXItemWidget;
  final BorderRadiusGeometry? borderRadiusOfItemWidget;

  ///DEFAULT:TRUE - TRUE i bordi sono su tutti i lati dell'XItemWidget se FALSE in vece si leva il bordo superiore
  final bool borderAll;

  ///DEFAULT:TRUE - FALSE per disattivare i bordi dell'XItemWidget
  final bool borderVisible;

  ///DEFAULT:FALSE - FALSE per disattivare solo il bordo infondo all'XItemWIdget
  final bool borderOnBottom;
  final AlignmentGeometry? alignmentChild;
  XItemWidget({
    Key? key,
    this.childrenForHeaders,
    this.titleAlignment,
    this.heightChildContainer,
    this.colorForAllBorder,
    this.borderAll = true,
    this.backGroundColorInternalWidget,
    this.titleStyle,
    this.btnOnTitle,
    this.child,
    this.title = "<No Title>",
    this.titleBackColor,
    this.borderVisible = true,
    this.borderOnBottom = false,
    this.borderRadiusOfItemWidget,
    this.decorationXItemWidget,
    this.borderWidth = 2.0,
    this.titleHeight,
    this.alignmentChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // var size = MediaQuery.of(context).size.height;
    return Container(
      // margin: EdgeInsets.all(3),
      decoration: decorationXItemWidget ??
          BoxDecoration(
              color: backGroundColorInternalWidget ?? Colors.grey[900],
              border: borderVisible
                  ? borderAll == true
                      ? Border.all(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!)
                      : Border(
                          bottom: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                          left: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                          right: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                        )
                  : null,
              borderRadius: borderRadiusOfItemWidget),
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        title != ""
            ? Container(
                color: titleBackColor,
                child: Row(
                  children: [
                    Expanded(
                      flex: 8,
                      child: Container(
                        height: titleHeight ?? 35,
                        decoration: BoxDecoration(
                            borderRadius: borderRadiusOfItemWidget,
                            color: colorForAllBorder ?? titleBackColor,
                            border: Border(
                              top: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                              left: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                              right: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                            )),
                        alignment: titleAlignment ?? Alignment.center,
                        child: Text(" " + title, style: titleStyle ?? XStyles.xStyTextForLabel()),
                      ),
                    ),
                    btnOnTitle == null
                        ? Container()
                        : Expanded(
                            child: Container(
                              color: titleBackColor,
                              height: 40,
                              child: btnOnTitle,
                            ),
                          ),
                  ],
                ),
              )
            : Container(),
        Row(children: childrenForHeaders ?? [Container()]),
        Container(
          color: backGroundColorInternalWidget ?? null,
          alignment: alignmentChild ?? Alignment.centerLeft,
          height: heightChildContainer ?? null,
          child: child ??
              Container(
                height: 200,
                width: double.infinity,
                alignment: Alignment.center,
                color: Colors.grey[900],
                child: Text("<Nessun Widget>", style: XStyles.xStyTextForLabel()),
              ),
        ),
      ]),
    );
  }
}

==> xwidgetsbase-6.8.5.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItemWidget.dart <==
part of xwidgetbase;

class XItemWidget extends StatelessWidget {
  ///Figlio che si trova dentro l'XItemWidget
  final Widget? child;
  final String title;
  final Color? titleBackColor;
  final double? titleHeight;
  final double? heightOfWidgetForEmptyList;

  ///Altezza del Container sotto il Title
  final double? heightChildContainer;

  ///BTN all'interno del container del Title e viene messo sulla destra
  final Widget? btnOnTitle;
  final TextStyle? titleStyle;

  ///Lista dei Widget per Headers per definire colonne in una lista che hai nel child dell'XItemWidget
  final List<Widget>? childrenForHeaders;
  final AlignmentGeometry? titleAlignment;
  double borderWidth;

  ///BackGroundColor per il child interno sotto il Title
  final Color? backGroundColorInternalWidget;
  final Color? colorForAllBorder;

  ///Setta per dare una Decoration specializzata per quest'Item
  final Decoration? decorationXItemWidget;
  final BorderRadiusGeometry? borderRadiusOfItemWidget;

  ///DEFAULT:TRUE - TRUE i bordi sono su tutti i lati dell'XItemWidget se FALSE in vece si leva il bordo superiore
  final bool borderAll;

  ///DEFAULT:TRUE - FALSE per disattivare i bordi dell'XItemWidget
  final bool borderVisible;

  ///DEFAULT:FALSE - FALSE per disattivare solo il bordo infondo all'XItemWIdget
  final bool borderOnBottom;
  final AlignmentGeometry? alignmentChild;
  XItemWidget({
    Key? key,
    this.childrenForHeaders,
    this.titleAlignment,
    this.heightOfWidgetForEmptyList,
    this.heightChildContainer,
    this.colorForAllBorder,
    this.borderAll = true,
    this.backGroundColorInternalWidget,
    this.titleStyle,
    this.btnOnTitle,
    this.child,
    this.title = "",
    this.titleBackColor,
    this.borderVisible = true,
    this.borderOnBottom = false,
    this.borderRadiusOfItemWidget,
    this.decorationXItemWidget,
    this.borderWidth = 2.0,
    this.titleHeight,
    this.alignmentChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // var size = MediaQuery.of(context).size.height;
    return Container(
      // margin: EdgeInsets.all(3),
      decoration: decorationXItemWidget ??
          BoxDecoration(
              color: backGroundColorInternalWidget ?? Colors.grey[900],
              border: borderVisible
                  ? borderAll == true

                      ///Tutti i bordi
                      ? Border.all(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!)

                      ///Tutti i bordi tranne quello in Top
                      : Border(
                          bottom: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                          left: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                          right: BorderSide(width: borderWidth, color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!),
                        )

                  ///Nessun bordo
                  : null,
              borderRadius: borderRadiusOfItemWidget),
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        title != ""
            ? Container(
                color: titleBackColor,
                child: Row(
                  children: [
                    Expanded(
                      flex: 8,
                      child: Container(
                        height: titleHeight ?? 35,
                        decoration: BoxDecoration(
                            borderRadius: borderRadiusOfItemWidget,
                            color: titleBackColor ?? colorForAllBorder,
                            border: borderVisible == true
                                ? Border(
                                    top: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                                  )
                                : Border(
                                    top: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                                    left: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                                    right: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                                    bottom: BorderSide(color: colorForAllBorder ?? titleBackColor ?? Colors.blue[50]!, width: borderWidth),
                                  )),
                        alignment: titleAlignment ?? Alignment.center,
                        child: Text(" " + title, style: titleStyle ?? XStyles.xStyTextForLabel()),
                      ),
                    ),
                    btnOnTitle == null
                        ? Container()
                        : Expanded(
                            child: Container(
                              color: titleBackColor,
                              height: 40,
                              child: btnOnTitle,
                            ),
                          ),
                  ],
                ),
              )
            : Container(),
        Row(children: childrenForHeaders ?? [Container()]),
        Container(
          color: backGroundColorInternalWidget ?? null,
          alignment: alignmentChild ?? Alignment.centerLeft,
          height: heightChildContainer ?? null,
          child: child ??
              Container(
                height: heightOfWidgetForEmptyList ?? 200,
                width: double.infinity,
                alignment: Alignment.center,
                color: Colors.grey[900],
                child: Text("<..nessuna..>", style: XStyles.xStyTextForLabel()),
              ),
        ),
      ]),
    );
  }
}
